var prefixProperties = require('inline-style-prefixer/lib/static/prefixProps');
var capitalizeString = require('inline-style-prefixer/lib/utils/capitalizeString');
var prefixPropertiesArray = Object.keys(prefixProperties);

var calc = require('inline-style-prefixer/lib/static/plugins/calc');
var cursor = require('inline-style-prefixer/lib/static/plugins/cursor');
var flex = require('inline-style-prefixer/lib/static/plugins/flex');
var sizing = require('inline-style-prefixer/lib/static/plugins/sizing');
var gradient = require('inline-style-prefixer/lib/static/plugins/gradient');
var transition = require('inline-style-prefixer/lib/static/plugins/transition');
// special flexbox specifications
var flexboxIE = require('inline-style-prefixer/lib/static/plugins/flexboxIE');
var flexboxOld = require('inline-style-prefixer/lib/static/plugins/flexboxOld');

var plugins = [
  calc,
  cursor,
  sizing,
  gradient,
  transition,
  flexboxIE,
  flexboxOld,
  flex
];

var hyphenate = require('./hyphenate-style-name');

module.exports = injectStyle;

function injectStyle(styletron, styles, media, pseudo) {
  var classString = '';
  for (var key in styles) {
    var val = styles[key];
    var valType = typeof val;
    if (valType === 'string' || valType === 'number') {
      // handle vendor prefixed properties
      for (var i = 0; i < prefixPropertiesArray.length; i++) {
        var prefix = prefixPropertiesArray[i];
        var properties = prefixProperties[prefix];
        if (properties[key]) {
          var prefixedPropName = prefix + capitalizeString(key);
          classString += injectWithPlugins(styletron, prefixedPropName, val, media, pseudo);
        }
      }
      // handle un-prefixed
      classString += injectWithPlugins(styletron, key, val, media, pseudo);
      continue;
    }
    if (Array.isArray(val)) {
      for (var i$1 = 0; i$1 < val.length; i$1++) {
        classString += injectWithPlugins(styletron, key, val, media, pseudo);
      }
      continue;
    }
    if (valType === 'object') {
      if (key[0] === ':') {
        classString += injectStyle(styletron, val, media, key);
        continue;
      }
      if (key.substring(0, 6) === '@media') {
        classString += injectStyle(styletron, val, key.substr(7), pseudo);
        continue;
      }
    }
  }
  return classString;
}

function injectWithPlugins(styletron, prop, val, media, pseudo) {
  var classString = '';
  for (var i = 0; i < plugins.length; i++) {
    var plugin = plugins[i];
    var res = plugin(prop, val);
    if (res) {
      for (var key in res) {
        var resVal = res[key];
        var hyphenated = hyphenate(key);
        if (Array.isArray(resVal)) {
          for (var j = 0; j < resVal.length; j++) {
            classString += ' ' + styletron.injectDeclaration({prop: hyphenated, val: resVal[j], media: media, pseudo: pseudo});
          }
        } else {
          classString += ' ' + styletron.injectDeclaration({prop: hyphenated, val: resVal, media: media, pseudo: pseudo});
        }
      }
    }
  }
  // inject original last
  classString += ' ' + styletron.injectDeclaration({prop: hyphenate(prop), val: val, media: media, pseudo: pseudo});
  return classString;
}
